@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+# Copyright (C) 2020 Red Hat, Inc.
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -24,15 +26,14 @@ extensions = [
 ]
 
 # openstackdocstheme options
-repository_name = 'openstack/oslo.reports'
-bug_project = 'oslo.reports'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/oslo.reports'
+openstackdocs_bug_project = 'oslo.reports'
+openstackdocs_bug_tag = ''
 
 # The master toctree document.
 master_doc = 'index'
 
 # General information about the project.
-project = u'oslo.reports'
 copyright = u'2014, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
@@ -43,17 +44,15 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # A list of ignored prefixes for module index sorting.
 modindex_common_prefix = ['oslo_reports.']
 
-
 # -- Options for HTML output -------------------------------------------------
 
 html_theme = 'openstackdocs'
 
-
 # -- sphinxcontrib.apidoc configuration --------------------------------------
 
 apidoc_module_dir = '../../oslo_reports'
